@@ -69,6 +69,7 @@ class FilterPyinotify(FileFilter):
 		# Pyinotify watch manager
 		self.__monitor = pyinotify.WatchManager()
 		self.__watches = dict()
+		self.__notifier = None
 		logSys.debug("Created FilterPyinotify")
 
 
@@ -90,6 +91,9 @@ class FilterPyinotify(FileFilter):
 				self._delFileWatcher(path)
 				# place a new one
 				self._addFileWatcher(path)
+		elif event.mask & pyinotify.IN_IGNORED:
+			# Caused when watch removed, either by rm_watch or file deletion
+			return
 
 		self._process_file(path)
 
@@ -118,9 +122,11 @@ class FilterPyinotify(FileFilter):
 
 	def _delFileWatcher(self, path):
 		wdInt = self.__watches[path]
-		wd = self.__monitor.rm_watch(wdInt)
-		if wd[wdInt]:
-			del self.__watches[path]
+		if wdInt is None:
+			return False
+		elif self.__monitor.get_path(wdInt) is None or \
+			self.__monitor.rm_watch(wdInt)[wdInt]:
+			self.__watches[path] = None
 			logSys.debug("Removed file watcher for %s", path)
 			return True
 		else:
@@ -151,6 +157,7 @@ class FilterPyinotify(FileFilter):
 	def _delLogPath(self, path):
 		if not self._delFileWatcher(path):
 			logSys.error("Failed to remove watch on path: %s", path)
+		del self.__watches[path]
 
 		path_dir = dirname(path)
 		if not len([k for k in self.__watches
@@ -184,9 +191,10 @@ class FilterPyinotify(FileFilter):
 	def stop(self):
 		super(FilterPyinotify, self).stop()
 
-		# Stop the notifier thread
-		self.__notifier.stop()
-		self.__notifier.join()			# to not exit before notifier does
+		# Stop the notifier thread if it was ran and notifier was created
+		if self.__notifier is not None:
+			self.__notifier.stop()
+			self.__notifier.join()			# to not exit before notifier does
 		self.__cleanup()				# for pedantic ones
 
 	##
@@ -211,6 +219,6 @@ class ProcessPyinotify(pyinotify.ProcessEvent):
 	def process_default(self, event):
 		try:
 			self.__FileFilter.callback(event, origin='Default ')
-		except Exception as e:
+		except Exception, e:
 			logSys.error("Error in FilterPyinotify callback: %s",
 				e, exc_info=logSys.getEffectiveLevel() <= logging.DEBUG)
