@@ -158,6 +158,20 @@ class BasicFilter(unittest.TestCase):
 		self.filter.setUseDns(False)
 		self.assertEqual(self.filter.getUseDns(), 'no')
 
+	def testBin(self):
+		# compare custom _bin against stock bin
+		from server.filter import _bin
+		if sys.version_info >= (2, 6):
+			from __builtin__ import bin
+			for n in (0, 1, 10, long(1), long(4294967168)):
+				self.assertEqual(_bin(n), bin(n))
+		else:
+			from server.filter import bin
+		self.assertEqual(bin(1), '0b1')
+		self.assertEqual(bin(0), '0b0')
+		self.assertEqual(bin(long(10)), '0b1010')
+
+
 
 class IgnoreIP(LogCaptureTestCase):
 
@@ -266,11 +280,15 @@ class LogFileFilterPoll(unittest.TestCase):
 class LogFileMonitor(LogCaptureTestCase):
 	"""Few more tests for FilterPoll API
 	"""
+
+	_setup_idx = 0  # to ease tracking of dangling opened files
+
 	def setUp(self):
 		"""Call before every test case."""
 		LogCaptureTestCase.setUp(self)
 		self.filter = self.name = 'NA'
-		_, self.name = tempfile.mkstemp('fail2ban', 'monitorfailures')
+		_, self.name = tempfile.mkstemp('fail2ban', 'monitorfailures-%d-' % LogFileMonitor._setup_idx)
+		LogFileMonitor._setup_idx += 1
 		self.file = open(self.name, 'a')
 		self.filter = FilterPoll(None)
 		self.filter.addLogPath(self.name)
@@ -536,12 +554,12 @@ def get_monitor_failures_testcase(Filter_):
 			self.assertEqual(self.filter.failManager.getFailTotal(), 3)
 
 			if interim_kill:
-				_killfile(None, self.name)
+				_killfile(self.file, self.name)
 				time.sleep(0.2)				  # let them know
 
 			# now create a new one to override old one
 			_copy_lines_between_files(GetFailures.FILENAME_01, self.name + '.new',
-									  n=100).close()
+									  n=100, skip=3).close()
 			os.rename(self.name + '.new', self.name)
 			self.assert_correct_last_attempt(GetFailures.FAILURES_01)
 			self.assertEqual(self.filter.failManager.getFailTotal(), 6)
