@@ -160,7 +160,7 @@ class Transmitter(TransmitterBase):
 		self.assertEqual(self.transm.proceed(["sleep", "1"]), (0, None))
 		t1 = time.time()
 		# Approx 1 second delay
-		self.assertAlmostEqual(t1 - t0, 1, places=2)
+		self.assertAlmostEqual(t1 - t0, 1, places=1)
 
 	def testAddJail(self):
 		jail2 = "TestJail2"
@@ -513,8 +513,13 @@ class TransmitterLogging(TransmitterBase):
 
 		self.setGetTest("logtarget", "STDOUT")
 		self.setGetTest("logtarget", "STDERR")
-		if sys.platform.lower().startswith('linux'):
-			self.setGetTest("logtarget", "SYSLOG")
+
+	def testLogTargetSYSLOG(self):
+		if not os.path.exists("/dev/log") and sys.version_info >= (2, 7):
+			raise unittest.SkipTest("'/dev/log' not present")
+		elif not os.path.exists("/dev/log"):
+			return
+		self.setGetTest("logtarget", "SYSLOG")
 
 	def testLogLevel(self):
 		self.setGetTest("loglevel", "4", 4)
